Snips NLU Rust Wrapper
======================

Installation
------------

It is recommended to install the package with a virtualenv:

.. code-block:: bash

    virtualenv venv
    . venv/bin/activate

The package is available on pypi, and can be installed with `pip`:

.. code-block:: bash

    pip install snips-nlu-rust
